@@ -149,7 +149,7 @@ class master:
             pass
 
         if "language" in node_request:
-            if "language" == "C++":
+            if node_request["language"] == "C++":
                 cmsg = msg.copy()
                 cmsg["port"] = str(cmsg["port"] )
                 self.server.send_info(msg)
@@ -199,7 +199,7 @@ class master:
                 msg = {'topic':topic, 'port': port, 'ip': self.IP, 'socket':socket_, "state":"success"}
 
             if "language" in node_request:
-                if "language" == "C++":
+                if node_request["language"] == "C++":
                     cmsg = msg.copy()
                     cmsg["port"] = str(cmsg["port"] )
                     self.server.send_info(msg)
